@@ -4,31 +4,27 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 // Own
 #include "barwidget.h"
 
 // Qt
 #include <QDebug>
 #include <QPainter>
-#include <QPen>
 #include <QPainterPath>
+#include <QPen>
 
 // KDE
 #include <KLocalizedString>
 
 // Parley
-#include "collectionwidget.h"  // for COLLWIDTH, etc
-
+#include "collectionwidget.h" // for COLLWIDTH, etc
 
 // FIXME: Find a better home for this variable.
 ConfidenceColors globalColors = ConfidenceColors();
 
-
 BarWidget::BarWidget(QWidget *parent)
     : QWidget(parent)
 {
-
 }
 
 BarWidget::BarWidget(WordCount *dueWords, QWidget *parent)
@@ -45,7 +41,6 @@ BarWidget::BarWidget(WordCount *dueWords, QWidget *parent)
     m_percentageCompleted = dueWords->percentageCompleted();
 }
 
-
 void BarWidget::setDue(WordCount &wc)
 {
     for (int i = 0; i <= KV_MAX_GRADE; ++i) {
@@ -56,7 +51,6 @@ void BarWidget::setDue(WordCount &wc)
     update();
 }
 
-
 void BarWidget::paintEvent(QPaintEvent *)
 {
     QPainter painter(this);
@@ -65,24 +59,23 @@ void BarWidget::paintEvent(QPaintEvent *)
     const int legendHeight = 45;
     const int legendOffsetY = 0;
     const int legendOffsetX = 0;
-    //const int alphaValueIncrement = 35;
+    // const int alphaValueIncrement = 35;
 
     int gradeBarWidth[9];
     gradeBarWidth[8] = 0;
     int gradeBarOffset[9];
     gradeBarOffset[8] = 0;
 
-    //qDebug() << "percentage completed: " << m_percentageCompleted;
-    //qDebug() << "Total due words: " << m_totalDueWords;
+    // qDebug() << "percentage completed: " << m_percentageCompleted;
+    // qDebug() << "Total due words: " << m_totalDueWords;
 
     if (m_percentageCompleted < 100) {
-        for(int j = 7; j >= 0; j--) {
-            gradeBarWidth[j] = (float)(m_dueWords[j]) / (float)(m_totalDueWords) * legendWidth;
-            gradeBarOffset[j] = gradeBarOffset[j+1] + gradeBarWidth[j+1];
+        for (int j = 7; j >= 0; j--) {
+            gradeBarWidth[j] = std::max(0.0, static_cast<double>(m_dueWords[j]) / static_cast<double>(m_totalDueWords) * legendWidth);
+            gradeBarOffset[j] = gradeBarOffset[j + 1] + gradeBarWidth[j + 1];
         }
-    }
-    else {
-        for(int j = 6; j >= 0; j--) {
+    } else {
+        for (int j = 6; j >= 0; j--) {
             gradeBarWidth[j] = 0;
             gradeBarOffset[j] = legendWidth;
         }
@@ -90,7 +83,7 @@ void BarWidget::paintEvent(QPaintEvent *)
         gradeBarOffset[7] = 0;
     }
     if (m_percentageCompleted < 100 && m_totalDueWords == 0) {
-        for(int j = 6; j >= 0; j--) {
+        for (int j = 6; j >= 0; j--) {
             gradeBarWidth[j] = 0;
             gradeBarOffset[j] = legendWidth;
         }
@@ -98,7 +91,7 @@ void BarWidget::paintEvent(QPaintEvent *)
         gradeBarOffset[7] = 0;
     }
 
-    QPen penBar(QColor(255,255,255));
+    QPen penBar(QColor(255, 255, 255));
     painter.setPen(penBar);
     QRectF roundedRect(0, 0, legendWidth, legendHeight);
     roundedRect.adjust(1, 1, -1, -1);
@@ -113,22 +106,19 @@ void BarWidget::paintEvent(QPaintEvent *)
         QColor color;
         if (m_totalDueWords == 0 && m_percentageCompleted < 100) {
             color = QColor(0, 0, 0, 128);
-        }
-        else {
+        } else {
             color = globalColors.longTermColors[i];
         }
         painter.setBrush(QBrush(color));
         painter.drawPath(barElementIntersectedPath);
     }
 
-    QPen pen(QColor(255,255,255));
-    //QPen pen(QColor(0, 0, 0));
+    QPen pen(QColor(255, 255, 255));
+    // QPen pen(QColor(0, 0, 0));
     painter.setPen(pen);
     if (m_percentageCompleted < 100) {
-        painter.drawText(0, 0, legendWidth, legendHeight, Qt::AlignCenter | Qt::TextWordWrap,
-			 i18np("%1 word due", "%1 words due", m_totalDueWords));
-    }
-    else {
+        painter.drawText(0, 0, legendWidth, legendHeight, Qt::AlignCenter | Qt::TextWordWrap, i18np("%1 word due", "%1 words due", m_totalDueWords));
+    } else {
         painter.drawText(0, 0, legendWidth, legendHeight, Qt::AlignCenter | Qt::TextWordWrap, i18n("Fully learned"));
     }
 }
