@@ -20,45 +20,44 @@ class KEduVocDocument;
 
 namespace Editor
 {
-
 /**
-* Show options to enable/disable the columns for each language of the current document
-*/
+ * Show options to enable/disable the columns for each language of the current document
+ */
 class VocabularyColumnsDialog : public QDialog
 {
     Q_OBJECT
 public:
     enum Roles {
         ColumnRole = 0x12,
-        LanguageRole = 0x18
+        LanguageRole = 0x18,
     };
 
     VocabularyColumnsDialog(KEduVocDocument *doc, QWidget *parent);
-    ~VocabularyColumnsDialog();
+    ~VocabularyColumnsDialog() override;
 
-    void accept() Q_DECL_OVERRIDE;
+    void accept() override;
 
 private:
     /**
-    * Initialize the gridlayout of the widget
-    * with one treeview for each language showing the possible columns
-    */
+     * Initialize the gridlayout of the widget
+     * with one treeview for each language showing the possible columns
+     */
     void createLanguagesLayout();
 
     /**
-    * Adds a language to the main gridlayout
-    */
+     * Adds a language to the main gridlayout
+     */
     void addLanguage(int language, QVBoxLayout *parent);
 
     /**
-    * Save the visible columns for each language in the document settings
-    */
+     * Save the visible columns for each language in the document settings
+     */
     void saveVisibleColumns();
 
-    DocumentSettings *m_settings;
-    QGridLayout *m_box;
-    KEduVocDocument *m_doc;
-    QMap <int, QStandardItemModel *> m_models;
+    DocumentSettings *m_settings{nullptr};
+    QGridLayout *m_box{nullptr};
+    KEduVocDocument *m_doc{nullptr};
+    QMap<int, QStandardItemModel *> m_models;
 };
 }
 
