@@ -15,27 +15,27 @@ class QLabel;
 
 namespace Practice
 {
-
 class LatexRenderer : public QObject
 {
     Q_OBJECT
 
 public:
-    explicit LatexRenderer(QObject* parent = 0);
-    void setResultLabel(QLabel *label) {
+    explicit LatexRenderer(QObject *parent = nullptr);
+    void setResultLabel(QLabel *label)
+    {
         m_label = label;
     }
     void renderLatex(QString tex);
 
-    static bool isLatex(const QString& tex);
+    static bool isLatex(const QString &tex);
 
-private slots:
+private Q_SLOTS:
     void convertToPs();
     void convertToImage();
     void latexRendered();
 
 private:
-    QLabel *m_label;
+    QLabel *m_label{nullptr};
     QString m_latexFilename;
 };
 
