@@ -77,7 +77,7 @@ void WrittenPracticeWidget::showQuestion()
     m_ui->solutionLabel->setText(QString());
     m_ui->helpLabel->clear();
 
-    for (QWidget *child : qAsConst(synonymWidgets)) {
+    for (QWidget *child : std::as_const(synonymWidgets)) {
         m_ui->synonymList->removeWidget(child);
         delete child;
     }
@@ -165,13 +165,13 @@ void WrittenPracticeWidget::setSolutionSound(const QUrl &soundUrl)
 
 void WrittenPracticeWidget::setSolutionPronunciation(const QString &pronunciationText)
 {
-    m_ui->solutionPronunciationLabel->setText('[' + pronunciationText + ']');
+    m_ui->solutionPronunciationLabel->setText(QLatin1Char('[') + pronunciationText + QLatin1Char(']'));
     m_ui->solutionPronunciationLabel->setEnabled(!pronunciationText.isNull());
 }
 
 void WrittenPracticeWidget::setQuestionPronunciation(const QString &pronunciationText)
 {
-    m_ui->questionPronunciationLabel->setText('[' + pronunciationText + ']');
+    m_ui->questionPronunciationLabel->setText(QLatin1Char('[') + pronunciationText + QLatin1Char(']'));
     m_ui->questionPronunciationLabel->setEnabled(!pronunciationText.isNull());
 }
 
